@@ -30,7 +30,7 @@ pub fn get_file_path_from_name_and_version(name: &str, version: &str, environmen
 
 fn get_plugin_dir_path(name: &str, version: &str, environment: &impl Environment) -> PathBuf {
   let cache_dir_path = environment.get_cache_dir();
-  cache_dir_path.join("plugins").join(&name).join(&version).join(&environment.cpu_arch())
+  cache_dir_path.join("plugins").join(name).join(version).join(&environment.cpu_arch())
 }
 
 fn get_plugin_executable_file_path(dir_path: &Path, plugin_name: &str) -> PathBuf {
@@ -121,6 +121,8 @@ struct ProcessPluginFile {
   version: String,
   #[serde(rename = "linux-x86_64")]
   linux_x86_64: Option<ProcessPluginPath>,
+  #[serde(rename = "linux-x86_64-musl")]
+  linux_x86_64_musl: Option<ProcessPluginPath>,
   #[serde(rename = "linux-aarch64")]
   linux_aarch64: Option<ProcessPluginPath>,
   #[serde(rename = "darwin-x86_64")]
@@ -212,6 +214,10 @@ fn get_os_path<'a>(plugin_file: &'a ProcessPluginFile, environment: &impl Enviro
       "aarch64" => plugin_file.linux_aarch64.as_ref().or(plugin_file.linux_x86_64.as_ref()),
       _ => None,
     },
+    "linux-musl" => match arch.as_str() {
+      "x86_64" => plugin_file.linux_x86_64_musl.as_ref(),
+      _ => None,
+    },
     "macos" => match arch.as_str() {
       "x86_64" => plugin_file.darwin_x86_64.as_ref(),
       "aarch64" => plugin_file.darwin_aarch64.as_ref().or(plugin_file.darwin_x86_64.as_ref()),
