@@ -15,12 +15,12 @@ const checksums = getChecksums();
 const infoJson = {
   version,
   checksums: {
-    "windows-x86_64": checksums.get("dprint-x86_64-pc-windows-msvc.zip"),
-    "darwin-x86_64": checksums.get("dprint-x86_64-apple-darwin.zip"),
-    "darwin-aarch64": checksums.get("dprint-aarch64-apple-darwin.zip"),
-    "linux-x86_64-gnu": checksums.get("dprint-x86_64-unknown-linux-gnu.zip"),
-    "linux-x86_64-musl": checksums.get("dprint-x86_64-unknown-linux-musl.zip"),
-    "linux-aarch64": checksums.get("dprint-aarch64-unknown-linux-gnu.zip"),
+    "x86_64-pc-windows-msvc": checksums.get("dprint-x86_64-pc-windows-msvc.zip"),
+    "x86_64-apple-darwin": checksums.get("dprint-x86_64-apple-darwin.zip"),
+    "aarch64-apple-darwin": checksums.get("dprint-aarch64-apple-darwin.zip"),
+    "x86_64-unknown-linux-gnu": checksums.get("dprint-x86_64-unknown-linux-gnu.zip"),
+    "x86_64-unknown-linux-musl": checksums.get("dprint-x86_64-unknown-linux-musl.zip"),
+    "aarch64-unknown-linux-gnu": checksums.get("dprint-aarch64-unknown-linux-gnu.zip"),
   },
 };
 fs.writeFileSync(infoJsonFilePath, JSON.stringify(infoJson, null, 2));
